@@ -1,5 +1,5 @@
 -- Arbitrary.hs: QuickCheck instances
--- Copyright © 2014-2018  Clint Adams
+-- Copyright © 2014-2019  Clint Adams
 -- This software is released under the terms of the Expat license.
 -- (See the LICENSE file).
 module Codec.Encryption.OpenPGP.Arbitrary
@@ -28,8 +28,7 @@ instance Arbitrary PKESK where
     pv <- arbitrary
     eoki <- arbitrary
     pka <- arbitrary
-    mpis <- arbitrary
-    return $ PKESK pv eoki pka mpis
+    PKESK pv eoki pka <$> arbitrary
 
 instance Arbitrary Signature where
   arbitrary = fmap Signature arbitrary
@@ -48,8 +47,7 @@ instance Arbitrary SignaturePayload where
         pka <- arbitrary
         ha <- arbitrary
         w16 <- arbitrary
-        mpis <- arbitrary
-        return (SigV3 st w32 eoki pka ha w16 mpis)
+        SigV3 st w32 eoki pka ha w16 <$> arbitrary
       four = do
         st <- arbitrary
         pka <- arbitrary
@@ -57,18 +55,15 @@ instance Arbitrary SignaturePayload where
         has <- arbitrary
         uhas <- arbitrary
         w16 <- arbitrary
-        mpis <- arbitrary
-        return (SigV4 st pka ha has uhas w16 mpis)
+        SigV4 st pka ha has uhas w16 <$> arbitrary
       other = do
         v <- choose (5, maxBound)
-        bs <- arbitrary
-        return (SigVOther v bs)
+        SigVOther v <$> arbitrary
 
 instance Arbitrary SigSubPacket where
   arbitrary = do
     crit <- arbitrary
-    pl <- arbitrary
-    return (SigSubPacket crit pl)
+    SigSubPacket crit <$> arbitrary
 
 instance Arbitrary SigSubPacketPayload where
   arbitrary =
