@@ -1,7 +1,10 @@
 -- KeyringParser.hs: OpenPGP (RFC4880) transferable keys parsing
--- Copyright © 2012-2019  Clint Adams
+-- Copyright © 2012-2020  Clint Adams
 -- This software is released under the terms of the Expat license.
 -- (See the LICENSE file).
+
+{-# LANGUAGE CPP #-}
+
 module Codec.Encryption.OpenPGP.KeyringParser
   (
  -- * Parsers
@@ -55,8 +58,13 @@ parseAChunk ::
   -> (([(r, s)], Maybe (Maybe (r -> r), Parser s r)), [r])
 parseAChunk _ a ([], Nothing) = error $ "Failure before " ++ show a
 parseAChunk op a (cr, Nothing) =
+#if MIN_VERSION_incremental_parser(0,4,0)
+  either error (\x -> (x, map fst cr)) (inspect (feed (mconcat (map snd cr) <> a) op))
+parseAChunk _ a (_, Just (_, p)) = either error (\x -> (x, [])) (inspect (feed a p))
+#else
   (inspect (feed (mconcat (map snd cr) <> a) op), map fst cr)
 parseAChunk _ a (_, Just (_, p)) = (inspect (feed a p), [])
+#endif
 
 finalizeParsing ::
      Monoid s
@@ -64,7 +72,11 @@ finalizeParsing ::
   -> (([(r, s)], Maybe (Maybe (r -> r), Parser s r)), [r])
 finalizeParsing ([], Nothing) = error "Unexpected finalization failure"
 finalizeParsing (cr, Nothing) = (([], Nothing), map fst cr)
+#if MIN_VERSION_incremental_parser(0,4,0)
+finalizeParsing (_, Just (_, p)) = either error finalizeParsing (inspect (feedEof p))
+#else
 finalizeParsing (_, Just (_, p)) = finalizeParsing (inspect (feedEof p))
+#endif
 
 anyTK :: Bool -> Parser [Pkt] (Maybe TK)
 anyTK True = publicTK True <|> secretTK True
