@@ -1,5 +1,5 @@
 -- Serialize.hs: OpenPGP (RFC4880) serialization (using cereal)
--- Copyright © 2012-2019  Clint Adams
+-- Copyright © 2012-2020  Clint Adams
 -- This software is released under the terms of the Expat license.
 -- (See the LICENSE file).
 module Codec.Encryption.OpenPGP.Serialize
@@ -473,7 +473,7 @@ putSubPacketLength l
     putWord8 (fromIntegral ((fromIntegral (l - 192) `shiftR` 8) + 192 :: Int)) >>
     putWord8 (fromIntegral (l - 192) .&. 0xff)
   | l <= 0xffffffff = putWord8 255 >> putWord32be (fromIntegral l)
-  | otherwise = fail ("too big (" ++ show l ++ ")")
+  | otherwise = error ("too big (" ++ show l ++ ")")
 
 getSigSubPacketType :: Get (Bool, Word8)
 getSigSubPacketType = do
@@ -556,7 +556,7 @@ putPacketLength l
     putWord8 (fromIntegral ((fromIntegral (l - 192) `shiftR` 8) + 192 :: Int)) >>
     putWord8 (fromIntegral (l - 192) .&. 0xff)
   | l < 0x100000000 = putWord8 255 >> putWord32be (fromIntegral l)
-  | otherwise = fail "partial body length support needed" -- FIXME
+  | otherwise = error "partial body length support needed" -- FIXME
 
 getS2K :: Get S2K
 getS2K = getS2K' =<< getWord8
@@ -950,7 +950,7 @@ bs2Point bs =
                    (uncurry
                       ECCT.Point
                       (bimap os2ip os2ip (B.splitAt (div l 2) xy)))
-            else fail $ "unknown type of point: " ++ show (B.unpack bs)
+            else Left $ "unknown type of point: " ++ show (B.unpack bs)
 
 putPubkey :: PKey -> Put
 putPubkey (UnknownPKey bs) = putLazyByteString bs
@@ -1102,7 +1102,7 @@ putSKAddendum (SUUnencrypted sk checksum) = do
     (if checksum == 0
        then BL.foldl (\a b -> mod (a + fromIntegral b) 0xffff) (0 :: Word16) skb
        else checksum) -- FIXME: be saner
-putSKAddendum _ = fail "Type not supported"
+putSKAddendum _ = error "Type not supported"
 
 symEncBlockSize :: SymmetricAlgorithm -> Int
 symEncBlockSize Plaintext = 0
