@@ -1,5 +1,5 @@
 -- SerializeForSigs.hs: OpenPGP (RFC4880) special serialization for signature purposes
--- Copyright © 2012-2016  Clint Adams
+-- Copyright © 2012-2020  Clint Adams
 -- This software is released under the terms of the Expat license.
 -- (See the LICENSE file).
 module Codec.Encryption.OpenPGP.SerializeForSigs
@@ -44,7 +44,7 @@ putPKPforFingerprinting (PublicKeyPkt pkp@(PKPayload V4 _ _ _ _)) = do
   putWord16be . fromIntegral $ BL.length bs
   putLazyByteString bs
 putPKPforFingerprinting _ =
-  fail "This should never happen (putPKPforFingerprinting)"
+  error "This should never happen (putPKPforFingerprinting)"
 
 putMPIforFingerprinting :: MPI -> Put
 putMPIforFingerprinting (MPI i) =
@@ -61,7 +61,7 @@ putPartialSigforSigning (SignaturePkt (SigV4 st pka ha hashed _ _ _)) = do
   putWord16be . fromIntegral . BL.length $ hb
   putLazyByteString hb
 putPartialSigforSigning _ =
-  fail "This should never happen (putPartialSigforSigning)"
+  error "This should never happen (putPartialSigforSigning)"
 
 putSigTrailer :: Pkt -> Put
 putSigTrailer (SignaturePkt (SigV4 _ _ _ hs _ _ _)) = do
@@ -69,12 +69,12 @@ putSigTrailer (SignaturePkt (SigV4 _ _ _ hs _ _ _)) = do
   putWord8 0xff
   putWord32be . fromIntegral . (+ 6) . BL.length $ runPut $ mapM_ put hs
             -- this +6 seems like a bug in RFC4880
-putSigTrailer _ = fail "This should never happen (putSigTrailer)"
+putSigTrailer _ = error "This should never happen (putSigTrailer)"
 
 putUforSigning :: Pkt -> Put
 putUforSigning u@(UserIdPkt _) = putUIDforSigning u
 putUforSigning u@(UserAttributePkt _) = putUAtforSigning u
-putUforSigning _ = fail "This should never happen (putUforSigning)"
+putUforSigning _ = error "This should never happen (putUforSigning)"
 
 putUIDforSigning :: Pkt -> Put
 putUIDforSigning (UserIdPkt u) = do
@@ -82,7 +82,7 @@ putUIDforSigning (UserIdPkt u) = do
   let bs = encodeUtf8 u
   putWord32be . fromIntegral . B.length $ bs
   putByteString bs
-putUIDforSigning _ = fail "This should never happen (putUIDforSigning)"
+putUIDforSigning _ = error "This should never happen (putUIDforSigning)"
 
 putUAtforSigning :: Pkt -> Put
 putUAtforSigning (UserAttributePkt us) = do
@@ -90,7 +90,7 @@ putUAtforSigning (UserAttributePkt us) = do
   let bs = runPut (mapM_ put us)
   putWord32be . fromIntegral . BL.length $ bs
   putLazyByteString bs
-putUAtforSigning _ = fail "This should never happen (putUAtforSigning)"
+putUAtforSigning _ = error "This should never happen (putUAtforSigning)"
 
 putSigforSigning :: Pkt -> Put
 putSigforSigning (SignaturePkt (SigV4 st pka ha hashed _ left16 mpis)) = do
@@ -98,7 +98,7 @@ putSigforSigning (SignaturePkt (SigV4 st pka ha hashed _ left16 mpis)) = do
   let bs = runPut $ put (SigV4 st pka ha hashed [] left16 mpis)
   putWord32be . fromIntegral . BL.length $ bs
   putLazyByteString bs
-putSigforSigning _ = fail "Non-V4 not implemented."
+putSigforSigning _ = error "Non-V4 not implemented."
 
 putKeyforSigning :: Pkt -> Put
 putKeyforSigning (PublicKeyPkt pkp) = putKeyForSigning' pkp
@@ -106,7 +106,7 @@ putKeyforSigning (PublicSubkeyPkt pkp) = putKeyForSigning' pkp
 putKeyforSigning (SecretKeyPkt pkp _) = putKeyForSigning' pkp
 putKeyforSigning (SecretSubkeyPkt pkp _) = putKeyForSigning' pkp
 putKeyforSigning x =
-  fail
+  error
     ("This should never happen (putKeyforSigning) " ++
      show (pktTag x) ++ "/" ++ show x)
 
