@@ -17,9 +17,8 @@ import GHC.Generics (Generic)
 import Codec.Encryption.OpenPGP.Types.Internal.PrettyUtils (prettyLBS)
 import Control.Applicative ((<|>))
 import Control.Arrow ((***))
-import Control.Lens (makeLenses)
+import Control.Lens (makeLenses, op, Wrapped)
 import Control.Monad (mzero)
-import Control.Newtype (Newtype(..))
 import Data.Aeson ((.=), object)
 import qualified Data.Aeson as A
 import qualified Data.Aeson.TH as ATH
@@ -213,9 +212,7 @@ newtype ThirtyTwoBitTimeStamp =
            , Typeable
            )
 
-instance Newtype ThirtyTwoBitTimeStamp Word32 where
-  pack = ThirtyTwoBitTimeStamp
-  unpack (ThirtyTwoBitTimeStamp o) = o
+instance Wrapped ThirtyTwoBitTimeStamp
 
 instance Pretty ThirtyTwoBitTimeStamp where
   pretty =
@@ -251,12 +248,10 @@ newtype ThirtyTwoBitDuration =
            , Typeable
            )
 
-instance Newtype ThirtyTwoBitDuration Word32 where
-  pack = ThirtyTwoBitDuration
-  unpack (ThirtyTwoBitDuration o) = o
+instance Wrapped ThirtyTwoBitDuration
 
 instance Pretty ThirtyTwoBitDuration where
-  pretty = pretty . concat . unfoldr durU . unpack
+  pretty = pretty . concat . unfoldr durU . op ThirtyTwoBitDuration
 
 $(ATH.deriveJSON ATH.defaultOptions ''ThirtyTwoBitDuration)
 
@@ -352,9 +347,7 @@ newtype TwentyOctetFingerprint =
     }
   deriving (Data, Eq, Generic, Ord, Show, Typeable)
 
-instance Newtype TwentyOctetFingerprint ByteString where
-  pack = TwentyOctetFingerprint
-  unpack (TwentyOctetFingerprint o) = o
+instance Wrapped TwentyOctetFingerprint
 
 -- FIXME: read-show
 instance Read TwentyOctetFingerprint where
@@ -378,10 +371,9 @@ newtype SpacedFingerprint =
   SpacedFingerprint
     { unSpacedFingerprint :: TwentyOctetFingerprint
     }
+  deriving (Data, Eq, Generic, Ord, Show, Typeable)
 
-instance Newtype SpacedFingerprint TwentyOctetFingerprint where
-  pack = SpacedFingerprint
-  unpack (SpacedFingerprint o) = o
+instance Wrapped SpacedFingerprint
 
 instance Pretty SpacedFingerprint where
   pretty =
@@ -389,7 +381,7 @@ instance Pretty SpacedFingerprint where
     punctuate space .
     map hsep .
     chunksOf 5 .
-    map pretty . chunksOf 4 . take 40 . bsToHexUpper . unTOF . unpack
+    map pretty . chunksOf 4 . take 40 . bsToHexUpper . unTOF . op SpacedFingerprint
 
 bsToHexUpper :: ByteString -> String
 bsToHexUpper = map toUpper . BLC8.unpack . B16L.encode
@@ -403,12 +395,10 @@ newtype EightOctetKeyId =
     }
   deriving (Data, Eq, Generic, Ord, Show, Typeable)
 
-instance Newtype EightOctetKeyId ByteString where
-  pack = EightOctetKeyId
-  unpack (EightOctetKeyId o) = o
+instance Wrapped EightOctetKeyId
 
 instance Pretty EightOctetKeyId where
-  pretty = pretty . bsToHexUpper . unpack
+  pretty = pretty . bsToHexUpper . op EightOctetKeyId
 
 -- FIXME: read-show
 instance Read EightOctetKeyId where
@@ -418,7 +408,7 @@ instance Read EightOctetKeyId where
 instance Hashable EightOctetKeyId
 
 instance A.ToJSON EightOctetKeyId where
-  toJSON e = object [T.pack "eoki" .= (bsToHexUpper . unpack) e]
+  toJSON e = object [T.pack "eoki" .= (bsToHexUpper . op EightOctetKeyId) e]
 
 instance A.FromJSON EightOctetKeyId where
   parseJSON (A.Object v) = EightOctetKeyId . read <$> v A..: T.pack "eoki"
@@ -433,12 +423,10 @@ newtype NotationName =
 instance Pretty NotationName where
   pretty = prettyLBS . unNotationName
 
-instance Newtype NotationName ByteString where
-  pack = NotationName
-  unpack (NotationName nn) = nn
+instance Wrapped NotationName
 
 instance A.ToJSON NotationName where
-  toJSON nn = object [T.pack "notationname" .= show (unpack nn)]
+  toJSON nn = object [T.pack "notationname" .= show (op NotationName nn)]
 
 instance A.FromJSON NotationName where
   parseJSON (A.Object v) = NotationName . read <$> v A..: T.pack "notationname"
@@ -453,12 +441,10 @@ newtype NotationValue =
 instance Pretty NotationValue where
   pretty = prettyLBS . unNotationValue
 
-instance Newtype NotationValue ByteString where
-  pack = NotationValue
-  unpack (NotationValue nv) = nv
+instance Wrapped NotationValue
 
 instance A.ToJSON NotationValue where
-  toJSON nv = object [T.pack "notationvalue" .= show (unpack nv)]
+  toJSON nv = object [T.pack "notationvalue" .= show (op NotationValue nv)]
 
 instance A.FromJSON NotationValue where
   parseJSON (A.Object v) =
@@ -702,9 +688,7 @@ newtype URL =
     }
   deriving (Data, Eq, Generic, Ord, Show, Typeable)
 
-instance Newtype URL URI where
-  pack = URL
-  unpack (URL o) = o
+instance Wrapped URL
 
 instance Hashable URL where
   hashWithSalt salt (URL (URI s a p q f)) =
@@ -713,10 +697,10 @@ instance Hashable URL where
     f
 
 instance Pretty URL where
-  pretty = pretty . (\uri -> uriToString id uri "") . unpack
+  pretty = pretty . (\uri -> uriToString id uri "") . op URL
 
 instance A.ToJSON URL where
-  toJSON u = object [T.pack "uri" .= (\uri -> uriToString id uri "") (unpack u)]
+  toJSON u = object [T.pack "uri" .= (\uri -> uriToString id uri "") (op URL u)]
 
 instance A.FromJSON URL where
   parseJSON (A.Object v) =
@@ -810,14 +794,12 @@ newtype MPI =
     }
   deriving (Data, Eq, Generic, Show, Typeable)
 
-instance Newtype MPI Integer where
-  pack = MPI
-  unpack (MPI o) = o
+instance Wrapped MPI
 
 instance Hashable MPI
 
 instance Pretty MPI where
-  pretty = pretty . unpack
+  pretty = pretty . op MPI
 
 $(ATH.deriveJSON ATH.defaultOptions ''MPI)
 
@@ -1055,15 +1037,13 @@ newtype IV =
            , Typeable
            )
 
-instance Newtype IV B.ByteString where
-  pack = IV
-  unpack (IV o) = o
+instance Wrapped IV
 
 instance Pretty IV where
-  pretty = pretty . ("iv:" ++) . bsToHexUpper . BL.fromStrict . unpack
+  pretty = pretty . ("iv:" ++) . bsToHexUpper . BL.fromStrict . op IV
 
 instance A.ToJSON IV where
-  toJSON = A.toJSON . show . unpack
+  toJSON = A.toJSON . show . op IV
 
 data DataType
   = BinaryData
@@ -1104,15 +1084,13 @@ newtype Salt =
     }
   deriving (Data, Eq, Generic, Hashable, Show, Typeable)
 
-instance Newtype Salt B.ByteString where
-  pack = Salt
-  unpack (Salt o) = o
+instance Wrapped Salt
 
 instance Pretty Salt where
-  pretty = pretty . ("salt:" ++) . bsToHexUpper . BL.fromStrict . unpack
+  pretty = pretty . ("salt:" ++) . bsToHexUpper . BL.fromStrict . op Salt
 
 instance A.ToJSON Salt where
-  toJSON = A.toJSON . show . unpack
+  toJSON = A.toJSON . show . op Salt
 
 newtype IterationCount =
   IterationCount
@@ -1132,12 +1110,10 @@ newtype IterationCount =
            , Typeable
            )
 
-instance Newtype IterationCount Int where
-  pack = IterationCount
-  unpack (IterationCount o) = o
+instance Wrapped IterationCount
 
 instance Pretty IterationCount where
-  pretty = pretty . unpack
+  pretty = pretty . op IterationCount
 
 $(ATH.deriveJSON ATH.defaultOptions ''IterationCount)
 
